package com.miaxis.app.controller.user;

import java.util.List;
import io.swagger.annotations.*;
import com.miaxis.common.core.domain.Response;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.ModelAttribute;
import com.miaxis.common.annotation.Log;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.enums.BusinessTypeEnum;
import com.miaxis.app.user.domain.UserInfo;
import com.miaxis.app.user.service.IUserInfoService;
import com.miaxis.common.utils.poi.ExcelUtil;
import com.miaxis.common.core.page.ResponsePageInfo;

/**
 * 【用户信息】Controller
 *
 * @author miaxis
 * @date 2020-12-22
 */
@RestController
@RequestMapping("/user/info")
@Api(tags={"【用户信息】Controller"})
public class UserInfoController extends BaseController{
    @Autowired
    private IUserInfoService userInfoService;

    /**
     * 查询用户信息列表
     */
    @PreAuthorize("@ss.hasPermi('user:info:list')")
    @GetMapping("/list")
    @ApiOperation("查询用户信息列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum",value = "当前页码" ,dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize",value = "每页数据量" , dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<UserInfo> list(@ModelAttribute UserInfo userInfo){
        startPage();
        List<UserInfo> list = userInfoService.selectUserInfoList(userInfo);
        return toResponsePageInfo(list);
    }

    /**
     * 导出用户信息列表
     */
    @PreAuthorize("@ss.hasPermi('user:info:export')")
    @Log(title = "用户信息", businessType = BusinessTypeEnum.EXPORT)
    @GetMapping("/export")
    @ApiOperation("导出用户信息列表Excel")
    public Response<String> export(@ModelAttribute UserInfo userInfo){
        List<UserInfo> list = userInfoService.selectUserInfoList(userInfo);
        ExcelUtil<UserInfo> util = new ExcelUtil<UserInfo>(UserInfo.class);
        return util.exportExcel(list, "info");
    }

    /**
     * 获取用户信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('user:info:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation("获取用户信息详细信息")
    public Response<UserInfo> getInfo(
            @ApiParam(name = "id", value = "用户信息参数", required = true)
            @PathVariable("id") Long id
    ){
        return Response.success(userInfoService.selectUserInfoById(id));
    }

    /**
     * 新增用户信息
     */
    @PreAuthorize("@ss.hasPermi('user:info:add')")
    @Log(title = "用户信息", businessType = BusinessTypeEnum.INSERT)
    @PostMapping
    @ApiOperation("新增用户信息")
    public Response<Integer> add(@RequestBody UserInfo userInfo){
        return toResponse(userInfoService.insertUserInfo(userInfo));
    }

    /**
     * 修改用户信息
     */
    @PreAuthorize("@ss.hasPermi('user:info:edit')")
    @Log(title = "用户信息", businessType = BusinessTypeEnum.UPDATE)
    @PutMapping
    @ApiOperation("修改用户信息")
    public Response<Integer> edit(@RequestBody UserInfo userInfo){
        return toResponse(userInfoService.updateUserInfo(userInfo));
    }

    /**
     * 删除用户信息
     */
    @PreAuthorize("@ss.hasPermi('user:info:remove')")
    @Log(title = "用户信息", businessType = BusinessTypeEnum.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除用户信息")
    public  Response<Integer> remove(
            @ApiParam(name = "ids", value = "用户信息ids参数", required = true)
            @PathVariable Long[] ids
    ){
        return toResponse(userInfoService.deleteUserInfoByIds(ids));
    }
}
